@@ -1,6 +1,6 @@
 // -*- c++ -*-
 //
-// $Id: pmpi++.h,v 1.1.1.1.2.1 2001/10/29 04:33:22 bbarrett Exp $
+// $Id: pmpi++.h,v 1.1.1.1.2.3 2003/01/19 17:38:47 brbarret Exp $
 //
 // Copyright 1997-2001, University of Notre Dame.
 // Authors: Jeffrey M. Squyres, Jeremy G. Siek, Michael P. McNally, and
@@ -46,6 +46,9 @@ public:
 
 
 #if ! _MPIPP_USEEXCEPTIONS_
+  /* Note that (while named in a silly way), this is not a global-level
+     extern int errno declaration.  It's in the MPI:: namespace, so it is
+     safe to do here.  Silly, but safe */
   _MPIPP_EXTERN_ _MPIPP_STATIC_ int errno;
 #endif
 
