@@ -1,38 +1,17 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
- * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	GDB
  *
- *	$Id: flatd.c,v 6.4 2001/03/29 16:47:53 jsquyres Exp $
+ * $Id: flatd.c,v 6.4.2.3 2002/12/19 19:30:54 jsquyres Exp $
  * 
  *	Function:	- OTB flat memory server
  *			- provides symbolic access to memory
@@ -46,6 +25,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include <sys/param.h>
 
 #include <events.h>
 #include <flatreq.h>
@@ -55,21 +35,24 @@
 #include <priority.h>
 #include <terror.h>
 #include <lamlog.h>
+#include <laminternal.h>
+#include <etc_misc.h>
+#include <args.h>
 
 /*
  * global functions
  */
 void			(*(fl_init()))();
 void			(*(flatd()))();
-void			flwipe();
-char			*flforget();
+void			flwipe(void);
+char			*flforget(int4 tag);
 
 /*
  * local functions
  */
-static void		flqclean();
-static void		flqget();
-static void		flqload();
+static void		flqclean(void);
+static void		flqget(void);
+static void		flqload(void);
 
 /*
  * external functions
@@ -98,7 +81,6 @@ static struct flregion	fltable[FLMAX];	/* flat address table */
  */
 void (*(
 fl_init()))()
-
 {
 	int		i;			/* index */
 
@@ -134,6 +116,7 @@ fl_init()))()
 	return((void (*)()) flatd);
 }
 
+
 /*
  *	flatd
  *
@@ -142,7 +125,6 @@ fl_init()))()
  */
 void
 (*(flatd()))()
-
 {
 	nhr.nh_node = request->flq_src_node;
 	nhr.nh_event = request->flq_src_event;
@@ -174,6 +156,7 @@ void
 	return((void (*)()) flatd);
 }
 
+
 /*
  *	flqload
  *
@@ -181,8 +164,7 @@ void
  *			- creates file in temporary directory
  */
 static void
-flqload()
-
+flqload(void)
 {
 	int		fd;			/* load file descriptor */
 	int		i;			/* favourite index */
@@ -226,7 +208,7 @@ flqload()
 /*
  * Create the temporary filename.
  */
-		fltable[i].fl_addr = malloc(FLPATHLEN);
+		fltable[i].fl_addr = malloc(MAXPATHLEN);
 
 		if (fltable[i].fl_addr == 0) {
 			fltable[i].fl_addr = EMPTY;
@@ -243,20 +225,48 @@ flqload()
 			return;
 		}
 
-		strcpy(fltable[i].fl_addr, buffer);
-		sprintf(buffer, "-flatd%d", flcount++);
-		strcat(fltable[i].fl_addr, buffer);
+		snprintf(fltable[i].fl_addr, MAXPATHLEN - 1,
+			 "%s-flatd%d", buffer, flcount++);
 		free(buffer);
 
 		fd = open(fltable[i].fl_addr,
 			  O_WRONLY | O_CREAT | O_APPEND, 0700);
 
-		if (fd < 0) {
-			fltable[i].fl_addr = EMPTY;
-			reply->flr_reply = errno;
-		} else {
-			reply->flr_reply = 0;
-			close(fd);
+		
+		/* If the LAM session directory
+		   (/tmp/lam-user@hostname) is on a networked
+		   filesystem, O_APPEND may fail (e.g., Linux/NFS --
+		   see open(2) on linux and search for "NFS").  So if
+		   we failed and got errno == EIO, give it another
+		   college try without the O_APPEND.  Be sure to
+		   unlink it first, because Linux/NFS will create a
+		   [broken] file entry in the directory, even if the
+		   open failed. <sigh> */
+		
+		if (fd < 0 && errno == EIO) {
+		  unlink(fltable[i].fl_addr);
+		  fd = open(fltable[i].fl_addr, O_WRONLY | O_CREAT, 0700);
+		}
+		
+                if (fd < 0) {
+		  reply->flr_reply = errno;
+		  lamlog("flatd: flqload - failed to create file %s",
+			 fltable[i].fl_addr);
+		  lamlog("flatd: flqload - errno %d", errno);
+		  
+		  /* On some stupid systems (e.g., Linux/NFS) a file
+		     may be created even though the open failed.  So
+		     be sure to unlink it (and ignore if unlink
+		     fails).  <sigh> */
+		  
+		  unlink(fltable[i].fl_addr);
+		  fltable[i].fl_addr = EMPTY;
+                } else {
+		  reply->flr_reply = 0;
+		  close(fd);
+		  lamlog("flatd: flqload - successfully created file %s",
+			 fltable[i].fl_addr);
+		  lamlog("flatd: flqload - file descriptor %d", fd);
 		}
 
 		if (nsend(&nhr)) lampanic("flatd (nsend)");
@@ -296,6 +306,7 @@ flqload()
 	}
 }
 
+
 /*
  *	flqget
  *
@@ -304,8 +315,7 @@ flqload()
  *			  associated with the tag
  */
 static void
-flqget()
-
+flqget(void)
 {
 	int		i;		/* favourite index */
 
@@ -328,14 +338,14 @@ flqget()
 	}
 }
 
+
 /*
  *	flqclean
  *
  *	Function:	- removes tag and associated file
  */
 static void
-flqclean()
-
+flqclean(void)
 {
 	int		i;
 
@@ -355,6 +365,7 @@ flqclean()
 	if (nsend(&nhr)) lampanic("flatd (nsend)");
 }
 
+
 /*
  *	flforget
  *
@@ -363,10 +374,7 @@ flqclean()
  *	Returns:	- local address
  */
 char *
-flforget(tag)
-
-int4			tag;
-
+flforget(int4 tag)
 {
 	int		i;
 	char		*temp;
@@ -384,6 +392,7 @@ int4			tag;
 	}
 }
 
+
 /*
  *	flwipe
  *
@@ -391,8 +400,7 @@ int4			tag;
  *			- should become a request someday
  */
 void
-flwipe()
-
+flwipe(void)
 {
 	int		i;
 
