@@ -1,38 +1,20 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
- * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: pqdetach.c,v 6.11 2001/03/29 19:31:33 jsquyres Exp $
+ *	$Id: pqdetach.c,v 6.11.2.3 2002/10/12 17:19:57 jsquyres Exp $
  * 
  *	Function:	- OTB kenyad
  *			- attaches and detaches kenya processes
@@ -293,8 +275,12 @@ childtrap()
 	  pid = waitpid(-1, &status, WNOHANG);
 		
 	  if (pid <= 0) {
+#if 0
+	    /* lamlog in signal handler is bad.  Looks like this
+	       causing issues on Solaris...  */
 	    if (errno != ECHILD && errno != EINVAL)
 	      lamlog("kenyad: get error for waitpid(), errno %d", errno);
+#endif
 	    return;
 	  }
 	  
@@ -306,12 +292,14 @@ childtrap()
 	    if (diesigfd >= 0)
 	      mwrite(diesigfd, (char *) &i, 1);
 
+#if 0
 	    if (WIFEXITED(status))
 	      lamlog("kenyad: child pid %d died with return code of %d",
 		     pid, WEXITSTATUS(status));
 	    else
 	      lamlog("kenyad: child pid %d died due to signal %d",
 		     pid, WTERMSIG(status));
+#endif
 	  }
 	}
 }
