@@ -1,38 +1,20 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
- * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: kernelio.c,v 6.13.2.1 2001/10/16 15:21:59 jsquyres Exp $
+ *	$Id: kernelio.c,v 6.13.2.3 2002/10/09 19:48:45 brbarret Exp $
  * 
  *	Function:	- receives kernel requests and send replies
  *			- moves messages between clients
@@ -247,6 +229,7 @@ kio_req()
 	int		i;
 	LAM_SOCK_OPTLEN_T length;
 	int		sd_new;		/* new client socket */
+	struct timeval to;
 	struct timeval	*pto;		/* timeout on this loop */
 	struct sockaddr_un
 			client_un;	/* client address */
@@ -266,7 +249,9 @@ kio_req()
 		if (tofunc == 0) {
 		    pto = 0;
 		} else {
-		    pto = &to_actual;
+		  to.tv_sec = to_actual.tv_sec;
+		  to.tv_usec = to_actual.tv_usec;
+		  pto = &to;
 /*
  * Declare a timeout based on a wild estimate.
  */
@@ -279,7 +264,11 @@ kio_req()
 
 		while (((nfd_ready = select(fd_max + 1, &readfds,
 			(fd_set *) 0, (fd_set *) &exceptfds, pto)) < 0) &&
-			(errno == EINTR));
+			(errno == EINTR)) {
+		  memcpy((char *) &readfds, (char *) &allfds, sizeof(fd_set));
+		  FD_SET(sd_kernel, &readfds);
+		  memcpy((char *) &exceptfds, (char *) &readfds, sizeof(fd_set));
+		}
 		if (nfd_ready < 0) 
 		  lampanic("lamd kernel: problem with select() (1)");
 /*
@@ -345,9 +334,27 @@ kio_req()
 	    if (FD_ISSET(fd_ready, &exceptfds))
 	      --nfd_ready;
 /*
- * Clean up errnoneous descriptor.
+ * Clean up errnoneous descriptor if there is nothing to read on that
+ * fd.  It seems that some OSes will set the fd in both fd_sets, which
+ * can cause problems for stdio forwarding (among others).  Because of
+ * this, we were leaking resources badly on those OSes.
+ *
+ * We do this here (rather than just shoving this below the interupt
+ * code) because we need to protect ourselves from reading off a
+ * client fd that has nothing to read, but has an error set.  So we
+ * have the following logic:
+ *
+ *  1) Deal with any erroneous fds that do not have something ready to
+ *     read
+ *  2) Deal with any client fds that have something to read - we know
+ *     that there is something to read because the fd made it through the
+ *     tests above to find the first fd that is either errneous or has
+ *     something to read AND this test, which eliminates the
+ *     erroroneous-only possibility.
+ *  3) Deal with any interupts 
  */
-	    if (FD_ISSET(fd_ready, &exceptfds)) {
+	    if (FD_ISSET(fd_ready, &exceptfds) && 
+		! FD_ISSET(fd_ready, &readfds)) {
 		knuke(kpfindport(fd_ready));
 		kio_close(fd_ready);
 	    }
