@@ -1,5 +1,5 @@
 /* 
- *   $Id: iowait.c,v 1.1.1.1 1999/03/17 18:52:54 jsquyres Exp $    
+ *   $Id: iowait.c,v 1.1.1.1 2000/09/06 20:01:53 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -7,6 +7,22 @@
 
 #include "mpioimpl.h"
 
+#ifdef HAVE_WEAK_SYMBOLS
+
+#if defined(HAVE_PRAGMA_WEAK)
+#pragma weak MPIO_Wait = PMPIO_Wait
+#elif defined(HAVE_PRAGMA_HP_SEC_DEF)
+#pragma _HP_SECONDARY_DEF PMPIO_Wait MPIO_Wait
+#elif defined(HAVE_PRAGMA_CRI_DUP)
+#pragma _CRI duplicate MPIO_Wait as PMPIO_Wait
+/* end of weak pragmas */
+#endif
+
+/* Include mapping from MPI->PMPI */
+#define MPIO_BUILD_PROFILING
+#include "mpioprof.h"
+#endif
+
 /* status object not filled currently */
 
 /*@
@@ -23,6 +39,9 @@ Output Parameters:
 int MPIO_Wait(MPIO_Request *request, MPI_Status *status)
 {
     int error_code;
+#ifndef PRINT_ERR_MSG
+    static char myname[] = "MPIO_WAIT";
+#endif
 #ifdef MPI_hpux
     int fl_xmpi;
 
@@ -35,8 +54,14 @@ int MPIO_Wait(MPIO_Request *request, MPI_Status *status)
 
     if ((*request < (MPIO_Request) 0) || 
 	     ((*request)->cookie != ADIOI_REQ_COOKIE)) {
-	printf("MPIO_Wait: Invalid request object\n");
+#ifdef PRINT_ERR_MSG
+	FPRINTF(stderr, "MPIO_Wait: Invalid request object\n");
 	MPI_Abort(MPI_COMM_WORLD, 1);
+#else
+	error_code = MPIR_Err_setmsg(MPI_ERR_REQUEST, MPIR_ERR_REQUEST_NULL,
+				     myname, (char *) 0, (char *) 0);
+	return ADIOI_Error(MPI_FILE_NULL, error_code, myname);
+#endif
     }
 
     switch ((*request)->optype) {
