@@ -1,5 +1,5 @@
 /* 
- *   $Id: info_getnks.c,v 1.1.1.1 1999/03/17 18:53:03 jsquyres Exp $    
+ *   $Id: info_getnks.c,v 1.1.1.1 2000/09/06 20:01:52 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -7,6 +7,22 @@
 
 #include "mpioimpl.h"
 
+#ifdef HAVE_WEAK_SYMBOLS
+
+#if defined(HAVE_PRAGMA_WEAK)
+#pragma weak MPI_Info_get_nkeys = PMPI_Info_get_nkeys
+#elif defined(HAVE_PRAGMA_HP_SEC_DEF)
+#pragma _HP_SECONDARY_DEF PMPI_Info_get_nkeys MPI_Info_get_nkeys
+#elif defined(HAVE_PRAGMA_CRI_DUP)
+#pragma _CRI duplicate MPI_Info_get_nkeys as PMPI_Info_get_nkeys
+/* end of weak pragmas */
+#endif
+
+/* Include mapping from MPI->PMPI */
+#define MPIO_BUILD_PROFILING
+#include "mpioprof.h"
+#endif
+
 /*@
     MPI_Info_get_nkeys - Returns the number of currently defined keys in info
 
@@ -23,7 +39,7 @@ int MPI_Info_get_nkeys(MPI_Info info, int *nkeys)
     MPI_Info curr;
 
     if ((info <= (MPI_Info) 0) || (info->cookie != MPIR_INFO_COOKIE)) {
-        printf("MPI_Info_get_nkeys: Invalid info object\n");
+        FPRINTF(stderr, "MPI_Info_get_nkeys: Invalid info object\n");
         MPI_Abort(MPI_COMM_WORLD, 1);
     }
 
