@@ -1,5 +1,5 @@
 /* 
- *   $Id: info_getnth.c,v 1.1.1.1 1999/03/17 18:53:04 jsquyres Exp $    
+ *   $Id: info_getnth.c,v 1.1.1.1 2000/09/06 20:01:52 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -7,6 +7,22 @@
 
 #include "mpioimpl.h"
 
+#ifdef HAVE_WEAK_SYMBOLS
+
+#if defined(HAVE_PRAGMA_WEAK)
+#pragma weak MPI_Info_get_nthkey = PMPI_Info_get_nthkey
+#elif defined(HAVE_PRAGMA_HP_SEC_DEF)
+#pragma _HP_SECONDARY_DEF PMPI_Info_get_nthkey MPI_Info_get_nthkey
+#elif defined(HAVE_PRAGMA_CRI_DUP)
+#pragma _CRI duplicate MPI_Info_get_nthkey as PMPI_Info_get_nthkey
+/* end of weak pragmas */
+#endif
+
+/* Include mapping from MPI->PMPI */
+#define MPIO_BUILD_PROFILING
+#include "mpioprof.h"
+#endif
+
 /*@
     MPI_Info_get_nthkey - Returns the nth defined key in info
 
@@ -25,12 +41,12 @@ int MPI_Info_get_nthkey(MPI_Info info, int n, char *key)
     int nkeys, i;
 
     if ((info <= (MPI_Info) 0) || (info->cookie != MPIR_INFO_COOKIE)) {
-        printf("MPI_Info_get_nthkey: Invalid info object\n");
+        FPRINTF(stderr, "MPI_Info_get_nthkey: Invalid info object\n");
         MPI_Abort(MPI_COMM_WORLD, 1);
     }
 
     if (key <= (char *) 0) {
-	printf("MPI_Info_get: key is an invalid address\n");
+	FPRINTF(stderr, "MPI_Info_get: key is an invalid address\n");
         MPI_Abort(MPI_COMM_WORLD, 1);
     }
 
@@ -42,7 +58,7 @@ int MPI_Info_get_nthkey(MPI_Info info, int n, char *key)
     }
 
     if ((n < 0) || (n >= nkeys)) {
-        printf("MPI_Info_get_nthkey: n is an invalid number\n");
+        FPRINTF(stderr, "MPI_Info_get_nthkey: n is an invalid number\n");
         MPI_Abort(MPI_COMM_WORLD, 1);
     }
 
