@@ -1,38 +1,17 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
- * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	GDB/NJN
  *
- *	$Id: kill.c,v 6.11 2001/02/16 17:10:35 jsquyres Exp $
+ * $Id: kill.c,v 6.11.2.4 2002/12/18 22:27:29 jsquyres Exp $
  *
  *	Function:	- kill file useful routines
  */
@@ -52,6 +31,7 @@
 #include <laminternal.h>
 #include <terror.h>
 #include <typical.h>
+#include <args.h>
 
 #define KILLDIR		"/tmp/lam-"
 
@@ -89,19 +69,28 @@ get_batchid(void)
     set = 1;
     ret[0] = ret[127] = '\0';
 
-    /*
-     * We only check for PBS at the moment 
-     */    
+    /* Did the user manually override the socket suffix? */
+
     if (getenv("LAM_MPI_SOCKET_SUFFIX") != NULL) {
       strncpy(ret, getenv("LAM_MPI_SOCKET_SUFFIX"), 127);
-    } else if (getenv("PBS_ENVIRONMENT") != NULL && 
+    } 
+
+    /* Are we running under a PBS job? */
+
+    else if (getenv("PBS_ENVIRONMENT") != NULL && 
 	       getenv("PBS_JOBID") != NULL) {
       strcpy(ret, "pbs");
       strncat(ret, getenv("PBS_JOBID"), 124);
+    } 
+
+    /* Are we running under an LSF job? */
+
+    else if (getenv("LSB_JOBID") != NULL && getenv("LSB_JOBINDEX")) {
+      snprintf(ret, 124, "lsf-%s-%s", getenv("LSB_JOBID"), 
+	       getenv("LSB_JOBINDEX"));
     }
-    /*
-     * Add more batch scheduler ID checks here...
-     */    
+
+    /* Add more batch scheduler ID checks here... */
   }
 
   return ret;
