@@ -1,38 +1,20 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
- * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN
  *
- *	$Id: registry.c,v 1.1.2.1 2001/11/12 21:46:40 brbarret Exp $
+ *	$Id: registry.c,v 1.1.2.3 2002/10/09 19:48:52 brbarret Exp $
  *
  *	Function:	- object registry
  *			- mechanism for registering semi-persistent
@@ -68,6 +50,8 @@
 
 #include <terror.h>
 #include <typical.h>
+#include <args.h>
+#include <laminternal.h>
 
 #ifndef MAXPATHLEN
 #define MAXPATHLEN	1024
@@ -102,6 +86,9 @@ static char		*lam_reg_tmpname();
 static char		*lam_reg_lockname();
 static void		clean_warning();
 static void		del_warning();
+static int              set_names(char *msg);
+static int              lock_registry(char *name);
+static void             unlock_registry(void);
 static int		filelock();
 
 /*
@@ -112,7 +99,9 @@ static FILE		*tmpf = 0;		/* temporary file */
 static char		*reg_fname = 0;		/* registry filename */
 static char		*reg_tmpname = 0;	/* temporary filename */
 static char		*reg_lockname = 0;	/* registry lock filename */
-static int		lockfd;			/* lock file descriptor */
+static char		*reg_mylockname = 0;	/* registry lock filename */
+static int		lockfd = -1;		/* lock file descriptor */
+static int              oexcl_works = 0;        /* does O_EXCL work? */
 
 #if LAM_HAVE_SYSV_SEMAPHORES
 
@@ -163,39 +152,18 @@ va_dcl
 	va_start(arglist);
 #endif
 
-	if (reg_fname == 0) {
-		reg_fname = lam_reg_filename();
-		if (reg_fname == 0) return;
+	if (set_names("lam_register_objects") == LAMERROR)
+	  return;
+	if (lock_registry("lam_register_objects") == LAMERROR)
+	  return;
 
-		reg_tmpname = lam_reg_tmpname();
-		if (reg_tmpname == 0) return;
-
-		reg_lockname = lam_reg_lockname();
-		if (reg_lockname == 0) return;
-	}
-/*
- * Open lock file atomically.
- */
-	lockfd = open(reg_lockname, O_RDWR | O_CREAT | O_EXCL, 0600);
-
-	if (lockfd == -1 && errno == EEXIST) {
-		lockfd = open(reg_lockname, O_RDWR, 0600);
-	}
-
-	if (lockfd == -1) return;
-
-	if (filelock(lockfd, F_SETLKW, F_WRLCK,
-			(off_t) 0, SEEK_SET, (off_t) 0) == -1) {
-	    close(lockfd);
-	    return;
-	}
 /*
  * Open the registry file and add the objects.
  */
 	fd = open(reg_fname, O_WRONLY | O_APPEND | O_CREAT, 0600);
 
 	if (fd < 0) {
-		close(lockfd);
+	        unlock_registry();
 		return;
 	}
 
@@ -212,14 +180,14 @@ va_dcl
 			break;
 		default:
 			close(fd);
-			close(lockfd);
+			unlock_registry();
 			va_end(arglist);
 			return;
 		}
 	}
 
 	close(fd);
-	close(lockfd);
+	unlock_registry();
 	va_end(arglist);
 }
 
@@ -245,33 +213,11 @@ char			*delobj;
     char		obj[MAXPATHLEN];	/* object name */
     char		type;			/* object type */
 
-    if (reg_fname == 0) {
-/*
- * Haven't previously opened the registry file.
- */
-	reg_fname = lam_reg_filename();
-	if (reg_fname == 0) return;
+    if (set_names("lam_deregister_object") == LAMERROR)
+      return;
+    if (lock_registry("lam_deregister_object") == LAMERROR)
+      return;
 
-	reg_tmpname = lam_reg_tmpname();
-	if (reg_tmpname == 0) return;
-
-	reg_lockname = lam_reg_lockname();
-	if (reg_lockname == 0) return;
-    }
-/*
- * Open and lock the registry lock file.
- */
-    lockfd = open(reg_lockname, O_RDWR, 0600);
-    if (lockfd < 0) {
-	del_warning("lam_deregister_object (open)");
-	return;
-    }
-
-    if (filelock(lockfd, F_SETLKW, F_WRLCK,
-		(off_t) 0, SEEK_SET, (off_t) 0) == -1) {
-	del_warning("lam_deregister_object (filelock)");
-	return;
-    }
 /*
  * Open the registry and temporary files.
  */
@@ -290,7 +236,7 @@ char			*delobj;
     if (fstatus.st_size == 0) {
 	fclose(f);
 	f = 0;
-	close(lockfd);
+	unlock_registry();
 	return;
     }
 
@@ -317,7 +263,7 @@ char			*delobj;
 	return;
     }
 
-    close(lockfd);
+    unlock_registry();
 }
 
 
@@ -335,40 +281,10 @@ lam_cleanup_objects()
     char		type;			/* shared structure type */
     char		obj[MAXPATHLEN];	/* object name */
 
-    lockfd = -1;
-
-    if (reg_fname == 0) {
-	reg_fname = lam_reg_filename();
-	if (reg_fname == 0) {
-	    clean_warning("lam_cleanup_objects (lam_reg_filename)");
-	    return;
-	}
-
-	reg_lockname = lam_reg_lockname();
-	if (reg_lockname == 0) {
-	    clean_warning("lam_cleanup_objects (lam_reg_lockname)");
-	    return;
-	}
-    }
-/*
- * Open lock file atomically.
- */
-    lockfd = open(reg_lockname, O_RDWR | O_CREAT | O_EXCL, 0600);
-
-    if (lockfd == -1 && errno == EEXIST) {
-	lockfd = open(reg_lockname, O_RDWR, 0600);
-    }
-
-    if (lockfd == -1) {
-	clean_warning("lam_cleanup_objects (open)");
-	return;
-    }
-
-    if (filelock(lockfd, F_SETLKW, F_WRLCK,
-		(off_t) 0, SEEK_SET, (off_t) 0) == -1) {
-	clean_warning("lam_cleanup_objects (filelock)");
-	return;
-    }
+    if (set_names("lam_cleanup_objects") == LAMERROR)
+      return;
+    if (lock_registry("lam_cleanup_objects") == LAMERROR)
+      return;
 /*
  * Open the registry file.
  */
@@ -376,7 +292,7 @@ lam_cleanup_objects()
 	if (errno != ENOENT) {
 	    clean_warning("lam_cleanup_objects (fopen)");
 	}
-	close(lockfd);
+	unlock_registry();
 	return;
     }
 
@@ -407,8 +323,7 @@ lam_cleanup_objects()
     f = 0;
 
     unlink(reg_fname);
-    close(lockfd);
-    lockfd = -1;
+    unlock_registry();
 
     if (reg_fname) {
 	free(reg_fname);
@@ -482,7 +397,7 @@ lam_reg_lockname()
 	fname = killname();
 	if (fname == 0) return(0);
 
-	strcat(fname, "-lock");
+	strcat(fname, "-registry-lock");
 	return(fname);
 }
 
@@ -505,10 +420,14 @@ char			*msg;
 
 	lam_errorstr(errmsg, sizeof(errmsg));
 	fprintf(stderr,
-		"%s: Warning: %s: deleting shared memory structures in \"%s\"",
-		msg, reg_fname, errmsg);
-
-	fprintf(stderr, "\tManual cleanup may be necessary. Try ipcrm.\n");
+		"%s: Warning: %s: deleting shared memory structures\n",
+		msg, reg_fname);
+	fprintf(stderr,
+		"%s: Warning: \"%s\"\n",
+		msg, errmsg);
+	fprintf(stderr, 
+		"%s: Warning: Manual cleanup may be necessary. Try ipcrm.\n",
+		msg);
 
 	if (f) {
 		fclose(f);
@@ -519,10 +438,6 @@ char			*msg;
 		tmpf = 0;
 		unlink(reg_tmpname);
 	}
-	if (lockfd >= 0) {
-		close(lockfd);
-		lockfd = -1;
-	}
 }
 
 
@@ -560,10 +475,163 @@ char			*msg;
 	tmpf = 0;
 	unlink(reg_tmpname);
     }
-    if (lockfd >= 0) {
-	close(lockfd);
-	lockfd = -1;
+}
+
+
+/*
+ *	set_names
+ *
+ *	Function:	- setup various filenames in static char*'s
+ *	Accepts:	- name of calling function
+ *	Returns:	- 0 or LAMERROR
+ */
+static int
+set_names(char *name)
+{
+  int fd;
+
+  if (reg_fname == 0) {
+    reg_fname = lam_reg_filename();
+    if (reg_fname == 0) {
+      fprintf(stderr, "%s: Problem obtaining registry filename\n", name);
+      return LAMERROR;
     }
+    
+    reg_tmpname = lam_reg_tmpname();
+    if (reg_tmpname == 0) {
+      fprintf(stderr, "%s: Problem obtaining temporary filename\n", name);
+      return LAMERROR;
+    }
+    
+    reg_lockname = lam_reg_lockname();
+    if (reg_lockname == 0) {
+      fprintf(stderr, "%s: Problem obtaining registry lock filename\n", name);
+      return LAMERROR;
+    }
+
+    /* Test to see if we can make the lockfile exclusively -- this may
+       fail if the lockfile is on NFS.  Make a unique filename and try
+       to open it with O_EXCL.  If we fail (note that we can't get
+       EEXIST, because this is a unique filename, so there's no
+       possibility that some other process ahs already created it),
+       then O_EXCL won't work.  See lock_registry(), below, for more
+       info on this. */
+
+    reg_mylockname = malloc(MAXPATHLEN);
+    snprintf(reg_mylockname, MAXPATHLEN - 1, "%s.%d", 
+	     reg_lockname, getpid());
+    fd = open(reg_mylockname, O_RDWR | O_CREAT | O_EXCL, 0600);
+    if (fd == -1) {
+      oexcl_works = 0;
+    } else {
+      oexcl_works = 1;
+      close(fd);
+    }
+
+    /* we need to unlink the filename regardless of whether the open
+       succeeded or not -- some broken filesystems (cough cough linux
+       NFS cough cough) will leave a broken entry in the directory
+       listing even if the create failed.  <sigh> */
+    
+    unlink(reg_mylockname);
+  }
+
+  return 0;
+}
+
+
+/*
+ *	lock_registry
+ *
+ *	Function:	- open the registry lockfile atomicly
+ *	Accepts:	- name of invoking function
+ *	Returns:	- 0 or LAMERROR
+ */
+static int
+lock_registry(char *name)
+{
+  struct stat statbuf;
+
+  /* This gets complicated.  If the lockfile is on NFS, open(2) (on
+     linux, at least) says that O_EXCL is broken.  Hence, we have to
+     do something different to assure atomicity. */
+
+  /* Standard method -- open lock file atomicly with O_EXCL */
+
+  if (oexcl_works == 1) {
+    lockfd = open(reg_lockname, O_RDWR | O_CREAT | O_EXCL, 0600);
+    
+    if (lockfd == -1 && errno == EEXIST)
+      lockfd = open(reg_lockname, O_RDWR, 0600);
+
+    if (lockfd == -1) {
+      return LAMERROR;
+    }
+  }
+
+  /* Alternative locking method using link() and stat().  Ideas behind
+     this came from the linux open(2) man page.  Make a new file that
+     is unique to this process (remember that it's already in a
+     directory that is specific to this host -- so using a PID in the
+     filename is sufficient to guarantee uniqueness), and try to hard
+     link it to the well-known lock name.  If the hard link succeeds,
+     or if the link count from a stat() of the unique file goes to 2,
+     we have successfully locked the registry.  Note that NFS can
+     sometimes incorrectly report a failure of link() -- this is why
+     we check stat() as well. */
+
+  else {
+    lockfd = open(reg_mylockname, O_RDWR | O_CREAT, 0600);
+    
+    if (lockfd == -1 && errno == EEXIST)
+      lockfd = open(reg_mylockname, O_RDWR, 0600);
+
+    if (lockfd == -1)
+      return LAMERROR;
+
+    link(reg_mylockname, reg_lockname);
+    if (stat(reg_mylockname, &statbuf) == -1) {
+      close(lockfd);
+      unlink(reg_mylockname);
+      return LAMERROR;
+    }
+
+    if (statbuf.st_nlink != 2) {
+      close(lockfd);
+      unlink(reg_mylockname);
+      return LAMERROR;
+    }
+  }  
+
+  if (filelock(lockfd, F_SETLKW, F_WRLCK,
+	       (off_t) 0, SEEK_SET, (off_t) 0) == -1) {
+    close(lockfd);
+    lockfd = -1;
+    if (oexcl_works == 0)
+      unlink(reg_mylockname);
+    unlink(reg_lockname);
+    return LAMERROR;
+  }
+  
+  return 0;
+}
+
+
+/*
+ *	unlock_registry
+ *
+ *	Function:	- remove our lock on the registry
+ */
+static void
+unlock_registry(void)
+{
+  if (lockfd != -1)
+    close(lockfd);
+  lockfd = -1;
+
+  if (oexcl_works == 0)
+    unlink(reg_mylockname);
+  unlink(reg_lockname);
 }
 
 
