@@ -1,38 +1,20 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
- * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN
  *
- *	$Id: spawnmult_f.c,v 6.6 1999/09/02 01:34:29 prijks Exp $
+ *	$Id: spawnmult_f.c,v 6.6.2.3 2003/01/18 21:55:03 brbarret Exp $
  *
  *	Function:	- MPI_Comm_spawn_multiple F77 wrapper
  */
@@ -50,19 +32,85 @@
 #include <typical.h>
 
 /*
- * private functions
+ *	f2c_argvs
+ *
+ *	Function:	- creates array of C argument vector from an
+ *			  F77 2-d array of strings
+ *	Accepts:	- first dimension of 2-d array
+ *			- F77 2-d array of strings
+ *			- length of strings
+ *			- array of C argument vectors (out)
+ *	Returns:	- 0 or LAMERROR
  */
-static int		f2c_argvs();
+static int
+f2c_argvs(int dim, char *array, int len, char ****argvs)
+{
+	int		argc;			/* argument vector count */
+	char		***argvarr;		/* array of argument vectors */
+	char		*cstr;			/* C string */
+	char		*p;
+	int		i, j;
 
+	if ((argvarr = (char ***) malloc(dim * sizeof(char **))) == 0) {
+		return(LAMERROR);
+	}
+
+	for (i = 0; i < dim; i++) {
+
+		argc = 0;
+		argvarr[i] = 0;
+		p = array + len * i;
+
+		while (1) {
+			cstr = lam_F2C_string(p, len);
+
+			if (cstr == 0) {
+				for (j = 0; j <= i; j++) {
+					argvfree(argvarr[j]);
+				}
+				return(LAMERROR);
+			}
+
+			if (*cstr == 0) break;
+
+			if (argvadd(&argc, &argvarr[i], cstr)) {
+				for (j = 0; j <= i; j++) {
+					argvfree(argvarr[j]);
+				}
+				return(LAMERROR);
+			}
+
+			p += len * dim;
+		}
+	}
+
+	*argvs = argvarr;
+	return(0);
+}
+
+/*
+ *	f2c_argvs_free
+ *
+ *	Function:	- free array of C argument vectors
+ *	Accepts:	- length of array
+ *			- array of C argument vectors
+ */
+static void 
+f2c_argvs_free(int n, char ***argvs)
+{
+	int i;
+
+	if (argvs) {
+		for (i = 0; i < n; i++)
+			argvfree(argvs[i]);
+
+		free(argvs);
+	}
+}
 
 void
-mpi_comm_spawn_multiple_(n, cmd, av, mps, infs, root, comm, icomm,
-			ec, ierr, nc, na)
-
-char			*cmd, *av;
-int			*n, *mps, *infs, *root, *comm, *icomm, *ec, *ierr;
-int			nc, na;
-
+mpi_comm_spawn_multiple_(int *n, char *cmd, char *av, int *mps, int *infs, 
+	int *root, int *comm, int *icomm, int *ec, int *ierr, int nc, int na)
 {
 	MPI_Comm	intercomm;
 	MPI_Info	*infos;
@@ -108,10 +156,10 @@ int			nc, na;
  * Convert F77 argument arrays to C argument vectors.
  */
 		if (f2c_argvs(*n, av, na, &argvs)) {
-			free((char *) infos);
 			lam_setfunc(BLKMPICOMMSPAWNMULT);
 			*ierr = lam_errfunc(GETHDL(*comm), BLKMPICOMMSPAWNMULT,
 					lam_mkerr(MPI_ERR_SPAWN, errno));
+			free((char *) infos);
 			return;
 		}
 	}
@@ -119,13 +167,11 @@ int			nc, na;
  * Convert F77 command strings to C array of commands.
  */
 	if (lam_F2C_argv(cmd, nc, &commands)) {
-		free((char *) infos);
-		for (i = 0; i < *n; i++) {
-			argvfree(argvs[i]);
-		}
 		lam_setfunc(BLKMPICOMMSPAWNMULT);
 		*ierr = lam_errfunc(GETHDL(*comm), BLKMPICOMMSPAWNMULT,
 					lam_mkerr(MPI_ERR_SPAWN, errno));
+		f2c_argvs_free(*n, argvs);
+		free((char *) infos);
 		return;
 	}
 
@@ -136,72 +182,8 @@ int			nc, na;
 		intercomm->c_f77handle = *icomm;
 	}
 
-	for (i = 0; i < *n; i++) {
-		argvfree(argvs[i]);
-	}
 	argvfree(commands);
+	f2c_argvs_free(*n, argvs);
 	free((char *) infos);
 }
 
-/*
- *	f2c_argvs
- *
- *	Function:	- creates array of C argument vector from an
- *			  F77 2-d array of strings
- *	Accepts:	- first dimension of 2-d array
- *			- F77 2-d array of strings
- *			- length of strings
- *			- array of C argument vectors (out)
- *	Returns:	- 0 or LAMERROR
- */
-static int
-f2c_argvs(dim, array, len, argvs)
-
-int			dim;
-char			*array;
-int			len;
-char			****argvs;
-
-{
-	int		argc;			/* argument vector count */
-	char		***argvarr;		/* array of argument vectors */
-	char		*cstr;			/* C string */
-	char		*p;
-	int		i, j;
-
-	if ((argvarr = (char ***) malloc(dim * sizeof(char **))) == 0) {
-		return(LAMERROR);
-	}
-
-	for (i = 0; i < dim; i++) {
-
-		argc = 0;
-		argvarr[i] = 0;
-		p = array + len * i;
-
-		while (1) {
-			cstr = lam_F2C_string(p, len);
-
-			if (cstr == 0) {
-				for (j = 0; j <= i; j++) {
-					argvfree(argvarr[j]);
-				}
-				return(LAMERROR);
-			}
-
-			if (*cstr == 0) break;
-
-			if (argvadd(&argc, &argvarr[i], cstr)) {
-				for (j = 0; j <= i; j++) {
-					argvfree(argvarr[j]);
-				}
-				return(LAMERROR);
-			}
-
-			p += len * dim;
-		}
-	}
-
-	*argvs = argvarr;
-	return(0);
-}
