@@ -1,35 +1,17 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
- * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
  *
- *	$Id: init.c,v 6.39.2.5 2001/11/18 01:57:11 jsquyres Exp $
+ *	$Id: init.c,v 6.39.2.9 2002/10/09 19:49:09 brbarret Exp $
  *
  *	Function:	- initialize the MPI session
  *			- the kitchen-sink of MPI
@@ -647,6 +629,7 @@ init_fcomplex_types(void)
 	MPI_F_COMPLEX->dt_label = TRDTFCOMPLEX;
 	MPI_F_COMPLEX->dt_commit = 1;
 	MPI_F_COMPLEX->dt_flags |= LAM_PREDEF;
+	MPI_F_COMPLEX->dt_nelem = 1;
 	strcpy(MPI_F_COMPLEX->dt_name, "MPI_COMPLEX");
 /*
  * Create MPI_DOUBLE_COMPLEX.
@@ -661,6 +644,7 @@ init_fcomplex_types(void)
 	MPI_F_DOUBLE_COMPLEX->dt_label = TRDTFDBLCOMPLEX;
 	MPI_F_DOUBLE_COMPLEX->dt_commit = 1;
 	MPI_F_DOUBLE_COMPLEX->dt_flags |= LAM_PREDEF;
+	MPI_F_DOUBLE_COMPLEX->dt_nelem = 1;
 	strcpy(MPI_F_DOUBLE_COMPLEX->dt_name, "MPI_DOUBLE_COMPLEX");
 
 	return(0);
@@ -870,7 +854,9 @@ init_op(void)
 	make_op(MPI_BXOR, lam_bxor);
 	make_op(MPI_MAXLOC, lam_maxloc);
 	make_op(MPI_MINLOC, lam_minloc);
+
 	make_op(MPI_REPLACE, lam_replace);
+	MPI_REPLACE->op_commute = 0;
 }
 
 /*
