@@ -1,38 +1,17 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
- * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD/JRV/NJN
  *
- *	$Id: lamreduce.c,v 6.6 2001/02/03 17:48:47 jsquyres Exp $
+ * $Id: lamreduce.c,v 6.6.2.3 2003/01/27 01:40:50 jsquyres Exp $
  *
  *	Function:	- all predefined reduce operations
  *			- min, max, sum, product
@@ -50,6 +29,11 @@
 /*
  * local structures
  */
+#if LAM_SIZEOF_LONG_DOUBLE
+struct ldblcplex { long double r; long double i; };
+#else
+struct ldblcplex { double r; double i; };
+#endif
 struct dblcplex { double r; double i; };
 struct complex { float r; float i; };
 struct fltflt { float v; float k; };
@@ -66,13 +50,7 @@ struct ldblint { double v; int k; };
 #endif
 
 void
-lam_max(invec, inoutvec, len, datatype)
-
-void			*invec;
-void			*inoutvec;
-int			*len;
-MPI_Datatype		*datatype;
-
+lam_max(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 {
 	int		i;
 	int		*piin, *piout;
@@ -90,8 +68,7 @@ MPI_Datatype		*datatype;
 #endif
 #if LAM_SIZEOF_LONG_LONG
 	long long	*pllin, *pllout;
-	unsigned long long
-			*pullin, *pullout;
+	unsigned long long *pullin, *pullout;
 #else
 	long		*pllin, *pllout;
 	unsigned long 	*pullin, *pullout;
@@ -238,13 +215,7 @@ MPI_Datatype		*datatype;
 }
 
 void
-lam_min(invec, inoutvec, len, datatype)
-
-void			*invec;
-void			*inoutvec;
-int			*len;
-MPI_Datatype		*datatype;
-
+lam_min(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 {
 	int		i;
 	int		*piin, *piout;
@@ -260,7 +231,14 @@ MPI_Datatype		*datatype;
 #else
 	double		*pldin, *pldout;
 #endif
-
+#if LAM_SIZEOF_LONG_LONG
+	long long	*pllin, *pllout;
+	unsigned long long *pullin, *pullout;
+#else
+	long		*pllin, *pllout;
+	unsigned long 	*pullin, *pullout;
+#endif
+	
 	if (*datatype == MPI_INT || *datatype == MPI_F_INTEGER) {
 		piin = (int *) invec;
 		piout = (int *) inoutvec;
@@ -365,18 +343,44 @@ MPI_Datatype		*datatype;
 		return;
 	}
 
+	if (*datatype == MPI_LONG_LONG_INT) {
+#if LAM_SIZEOF_LONG_LONG
+		pllin = (long long *) invec;
+		pllout = (long long *) inoutvec;
+#else
+		pllin = (long *) invec;
+		pllout = (long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pllin, ++pllout) {
+			if (*pllin < *pllout) {
+				*pllout = *pllin;
+			}
+		}
+		return;
+	}
+
+	if (*datatype == MPI_UNSIGNED_LONG_LONG) {
+#if LAM_SIZEOF_LONG_LONG
+		pullin = (unsigned long long *) invec;
+		pullout = (unsigned long long *) inoutvec;
+#else
+		pullin = (unsigned long *) invec;
+		pullout = (unsigned long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pullin, ++pullout) {
+			if (*pullin < *pullout) {
+				*pullout = *pullin;
+			}
+		}
+		return;
+	}
+
 	(void) lam_errfunc(MPI_COMM_WORLD,
 				lam_getfunc(), lam_mkerr(MPI_ERR_OP, 0));
 }
 
 void
-lam_sum(invec, inoutvec, len, datatype)
-
-void			*invec;
-void			*inoutvec;
-int			*len;
-MPI_Datatype		*datatype;
-
+lam_sum(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 {
 	int		i;
 	int		*piin, *piout;
@@ -394,6 +398,13 @@ MPI_Datatype		*datatype;
 #else
 	double		*pldin, *pldout;
 #endif
+#if LAM_SIZEOF_LONG_LONG
+	long long	*pllin, *pllout;
+	unsigned long long *pullin, *pullout;
+#else
+	long		*pllin, *pllout;
+	unsigned long 	*pullin, *pullout;
+#endif
 
 	if (*datatype == MPI_INT || *datatype == MPI_F_INTEGER) {
 		piin = (int *) invec;
@@ -501,18 +512,40 @@ MPI_Datatype		*datatype;
 		return;
 	}
 
+	if (*datatype == MPI_LONG_LONG_INT) {
+#if LAM_SIZEOF_LONG_LONG
+		pllin = (long long *) invec;
+		pllout = (long long *) inoutvec;
+#else
+		pllin = (long *) invec;
+		pllout = (long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pllin, ++pllout) {
+			*pllout += *pllin;
+		}
+		return;
+	}
+
+	if (*datatype == MPI_UNSIGNED_LONG_LONG) {
+#if LAM_SIZEOF_LONG_LONG
+		pullin = (unsigned long long *) invec;
+		pullout = (unsigned long long *) inoutvec;
+#else
+		pullin = (unsigned long *) invec;
+		pullout = (unsigned long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pullin, ++pullout) {
+			*pullout += *pullin;
+		}
+		return;
+	}
+
 	(void) lam_errfunc(MPI_COMM_WORLD,
 				lam_getfunc(), lam_mkerr(MPI_ERR_OP, 0));
 }
 
 void
-lam_prod(invec, inoutvec, len, datatype)
-
-void			*invec;
-void			*inoutvec;
-int			*len;
-MPI_Datatype		*datatype;
-
+lam_prod(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 {
 	int		i;
 	int		*piin, *piout;
@@ -532,6 +565,13 @@ MPI_Datatype		*datatype;
 #else
 	double		*pldin, *pldout;
 #endif
+#if LAM_SIZEOF_LONG_LONG
+	long long	*pllin, *pllout;
+	unsigned long long *pullin, *pullout;
+#else
+	long		*pllin, *pllout;
+	unsigned long 	*pullin, *pullout;
+#endif
 
 	if (*datatype == MPI_INT || *datatype == MPI_F_INTEGER) {
 		piin = (int *) invec;
@@ -643,18 +683,40 @@ MPI_Datatype		*datatype;
 		return;
 	}
 
+	if (*datatype == MPI_LONG_LONG_INT) {
+#if LAM_SIZEOF_LONG_LONG
+		pllin = (long long *) invec;
+		pllout = (long long *) inoutvec;
+#else
+		pllin = (long *) invec;
+		pllout = (long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pllin, ++pllout) {
+			*pllout *= *pllin;
+		}
+		return;
+	}
+
+	if (*datatype == MPI_UNSIGNED_LONG_LONG) {
+#if LAM_SIZEOF_LONG_LONG
+		pullin = (unsigned long long *) invec;
+		pullout = (unsigned long long *) inoutvec;
+#else
+		pullin = (unsigned long *) invec;
+		pullout = (unsigned long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pullin, ++pullout) {
+			*pullout *= *pullin;
+		}
+		return;
+	}
+
 	(void) lam_errfunc(MPI_COMM_WORLD,
 				lam_getfunc(), lam_mkerr(MPI_ERR_OP, 0));
 }
 
 void
-lam_land(invec, inoutvec, len, datatype)
-
-void			*invec;
-void			*inoutvec;
-int			*len;
-MPI_Datatype		*datatype;
-
+lam_land(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 {
 	int		i;
 	int		*piin, *piout;
@@ -663,6 +725,13 @@ MPI_Datatype		*datatype;
 	unsigned short	*pusin, *pusout;
 	unsigned	*puin, *puout;
 	unsigned long	*pulin, *pulout;
+#if LAM_SIZEOF_LONG_LONG
+	long long	*pllin, *pllout;
+	unsigned long long *pullin, *pullout;
+#else
+	long		*pllin, *pllout;
+	unsigned long 	*pullin, *pullout;
+#endif
 
 	if ((*datatype == MPI_INT) || (*datatype == MPI_F_LOGICAL)
 			|| (*datatype == MPI_F_INTEGER)) {
@@ -719,18 +788,40 @@ MPI_Datatype		*datatype;
 		return;
 	}
 
+	if (*datatype == MPI_LONG_LONG_INT) {
+#if LAM_SIZEOF_LONG_LONG
+		pllin = (long long *) invec;
+		pllout = (long long *) inoutvec;
+#else
+		pllin = (long *) invec;
+		pllout = (long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pllin, ++pllout) {
+			*pllout = *pllout && *pllin;
+		}
+		return;
+	}
+
+	if (*datatype == MPI_UNSIGNED_LONG_LONG) {
+#if LAM_SIZEOF_LONG_LONG
+		pullin = (unsigned long long *) invec;
+		pullout = (unsigned long long *) inoutvec;
+#else
+		pullin = (unsigned long *) invec;
+		pullout = (unsigned long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pullin, ++pullout) {
+			*pullout = *pullout && *pullin;	
+		}
+		return;
+	}
+
 	(void) lam_errfunc(MPI_COMM_WORLD,
 				lam_getfunc(), lam_mkerr(MPI_ERR_OP, 0));
 }
 
 void
-lam_lor(invec, inoutvec, len, datatype)
-
-void			*invec;
-void			*inoutvec;
-int			*len;
-MPI_Datatype		*datatype;
-
+lam_lor(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 {
 	int		i;
 	int		*piin, *piout;
@@ -739,6 +830,13 @@ MPI_Datatype		*datatype;
 	unsigned short	*pusin, *pusout;
 	unsigned	*puin, *puout;
 	unsigned long	*pulin, *pulout;
+#if LAM_SIZEOF_LONG_LONG
+	long long	*pllin, *pllout;
+	unsigned long long *pullin, *pullout;
+#else
+	long		*pllin, *pllout;
+	unsigned long 	*pullin, *pullout;
+#endif
 
 	if ((*datatype == MPI_INT) || (*datatype == MPI_F_LOGICAL)
 			|| (*datatype == MPI_F_INTEGER)) {
@@ -795,18 +893,40 @@ MPI_Datatype		*datatype;
 		return;
 	}
 
+	if (*datatype == MPI_LONG_LONG_INT) {
+#if LAM_SIZEOF_LONG_LONG
+		pllin = (long long *) invec;
+		pllout = (long long *) inoutvec;
+#else
+		pllin = (long *) invec;
+		pllout = (long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pllin, ++pllout) {
+			*pllout = *pllout || *pllin;
+		}
+		return;
+	}
+
+	if (*datatype == MPI_UNSIGNED_LONG_LONG) {
+#if LAM_SIZEOF_LONG_LONG
+		pullin = (unsigned long long *) invec;
+		pullout = (unsigned long long *) inoutvec;
+#else
+		pullin = (unsigned long *) invec;
+		pullout = (unsigned long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pullin, ++pullout) {
+			*pullout = *pullout || *pullin;	
+		}
+		return;
+	}
+
 	(void) lam_errfunc(MPI_COMM_WORLD,
 				lam_getfunc(), lam_mkerr(MPI_ERR_OP, 0));
 }
 
 void
-lam_lxor(invec, inoutvec, len, datatype)
-
-void			*invec;
-void			*inoutvec;
-int			*len;
-MPI_Datatype		*datatype;
-
+lam_lxor(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 {
 	int		i;
 	int		*piin, *piout;
@@ -815,6 +935,13 @@ MPI_Datatype		*datatype;
 	unsigned short	*pusin, *pusout;
 	unsigned	*puin, *puout;
 	unsigned long	*pulin, *pulout;
+#if LAM_SIZEOF_LONG_LONG
+	long long	*pllin, *pllout;
+	unsigned long long *pullin, *pullout;
+#else
+	long		*pllin, *pllout;
+	unsigned long 	*pullin, *pullout;
+#endif
 
 	if ((*datatype == MPI_INT) || (*datatype == MPI_F_LOGICAL)
 			|| (*datatype == MPI_F_INTEGER)) {
@@ -871,18 +998,41 @@ MPI_Datatype		*datatype;
 		return;
 	}
 
+	if (*datatype == MPI_LONG_LONG_INT) {
+#if LAM_SIZEOF_LONG_LONG
+		pllin = (long long *) invec;
+		pllout = (long long *) inoutvec;
+#else
+		pllin = (long *) invec;
+		pllout = (long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pllin, ++pllout) {
+			*pllout = (*pllout || *pllin) && !(*pllout && *pllin);
+		}
+		return;
+	}
+
+	if (*datatype == MPI_UNSIGNED_LONG_LONG) {
+#if LAM_SIZEOF_LONG_LONG
+		pullin = (unsigned long long *) invec;
+		pullout = (unsigned long long *) inoutvec;
+#else
+		pullin = (unsigned long *) invec;
+		pullout = (unsigned long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pullin, ++pullout) {
+			*pullout = (*pullout || *pullin)
+					&& !(*pullout && *pullin);
+		}
+		return;
+	}
+
 	(void) lam_errfunc(MPI_COMM_WORLD,
 				lam_getfunc(), lam_mkerr(MPI_ERR_OP, 0));
 }
 
 void
-lam_band(invec, inoutvec, len, datatype)
-
-void			*invec;
-void			*inoutvec;
-int			*len;
-MPI_Datatype		*datatype;
-
+lam_band(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 {
 	int		i;
 	int		*piin, *piout;
@@ -892,6 +1042,13 @@ MPI_Datatype		*datatype;
 	unsigned	*puin, *puout;
 	unsigned long	*pulin, *pulout;
 	unsigned char	*pucin, *pucout;
+#if LAM_SIZEOF_LONG_LONG
+	long long	*pllin, *pllout;
+	unsigned long long *pullin, *pullout;
+#else
+	long		*pllin, *pllout;
+	unsigned long 	*pullin, *pullout;
+#endif
 
 	if ((*datatype == MPI_INT) || (*datatype == MPI_F_LOGICAL)
 			|| (*datatype == MPI_F_INTEGER)) {
@@ -957,18 +1114,40 @@ MPI_Datatype		*datatype;
 		return;
 	}
 
+	if (*datatype == MPI_LONG_LONG_INT) {
+#if LAM_SIZEOF_LONG_LONG
+		pllin = (long long *) invec;
+		pllout = (long long *) inoutvec;
+#else
+		pllin = (long *) invec;
+		pllout = (long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pllin, ++pllout) {
+			*pllout &= *pllin;
+		}
+		return;
+	}
+
+	if (*datatype == MPI_UNSIGNED_LONG_LONG) {
+#if LAM_SIZEOF_LONG_LONG
+		pullin = (unsigned long long *) invec;
+		pullout = (unsigned long long *) inoutvec;
+#else
+		pullin = (unsigned long *) invec;
+		pullout = (unsigned long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pullin, ++pullout) {
+			*pullout &= *pullin;
+		}
+		return;
+	}
+
 	(void) lam_errfunc(MPI_COMM_WORLD,
 				lam_getfunc(), lam_mkerr(MPI_ERR_OP, 0));
 }
 
 void
-lam_bor(invec, inoutvec, len, datatype)
-
-void			*invec;
-void			*inoutvec;
-int			*len;
-MPI_Datatype		*datatype;
-
+lam_bor(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 {
 	int		i;
 	int		*piin, *piout;
@@ -978,6 +1157,13 @@ MPI_Datatype		*datatype;
 	unsigned	*puin, *puout;
 	unsigned long	*pulin, *pulout;
 	unsigned char	*pucin, *pucout;
+#if LAM_SIZEOF_LONG_LONG
+	long long	*pllin, *pllout;
+	unsigned long long *pullin, *pullout;
+#else
+	long		*pllin, *pllout;
+	unsigned long 	*pullin, *pullout;
+#endif
 
 	if ((*datatype == MPI_INT) || (*datatype == MPI_F_LOGICAL)
 			|| (*datatype == MPI_F_INTEGER)) {
@@ -1043,18 +1229,40 @@ MPI_Datatype		*datatype;
 		return;
 	}
 
+	if (*datatype == MPI_LONG_LONG_INT) {
+#if LAM_SIZEOF_LONG_LONG
+		pllin = (long long *) invec;
+		pllout = (long long *) inoutvec;
+#else
+		pllin = (long *) invec;
+		pllout = (long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pllin, ++pllout) {
+			*pllout |= *pllin;
+		}
+		return;
+	}
+
+	if (*datatype == MPI_UNSIGNED_LONG_LONG) {
+#if LAM_SIZEOF_LONG_LONG
+		pullin = (unsigned long long *) invec;
+		pullout = (unsigned long long *) inoutvec;
+#else
+		pullin = (unsigned long *) invec;
+		pullout = (unsigned long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pullin, ++pullout) {
+			*pullout |= *pullin;
+		}
+		return;
+	}
+
 	(void) lam_errfunc(MPI_COMM_WORLD,
 				lam_getfunc(), lam_mkerr(MPI_ERR_OP, 0));
 }
 
 void
-lam_bxor(invec, inoutvec, len, datatype)
-
-void			*invec;
-void			*inoutvec;
-int			*len;
-MPI_Datatype		*datatype;
-
+lam_bxor(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 {
 	int		i;
 	int		*piin, *piout;
@@ -1064,6 +1272,13 @@ MPI_Datatype		*datatype;
 	unsigned	*puin, *puout;
 	unsigned long	*pulin, *pulout;
 	unsigned char	*pucin, *pucout;
+#if LAM_SIZEOF_LONG_LONG
+	long long	*pllin, *pllout;
+	unsigned long long *pullin, *pullout;
+#else
+	long		*pllin, *pllout;
+	unsigned long 	*pullin, *pullout;
+#endif
 
 	if ((*datatype == MPI_INT) || (*datatype == MPI_F_LOGICAL)
 			|| (*datatype == MPI_F_INTEGER)) {
@@ -1129,18 +1344,40 @@ MPI_Datatype		*datatype;
 		return;
 	}
 
+	if (*datatype == MPI_LONG_LONG_INT) {
+#if LAM_SIZEOF_LONG_LONG
+		pllin = (long long *) invec;
+		pllout = (long long *) inoutvec;
+#else
+		pllin = (long *) invec;
+		pllout = (long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pllin, ++pllout) {
+			*pllout ^= *pllin;
+		}
+		return;
+	}
+
+	if (*datatype == MPI_UNSIGNED_LONG_LONG) {
+#if LAM_SIZEOF_LONG_LONG
+		pullin = (unsigned long long *) invec;
+		pullout = (unsigned long long *) inoutvec;
+#else
+		pullin = (unsigned long *) invec;
+		pullout = (unsigned long *) inoutvec;
+#endif
+		for (i = 0; i < *len; ++i, ++pullin, ++pullout) {
+			*pullout ^= *pullin;
+		}
+		return;
+	}
+
 	(void) lam_errfunc(MPI_COMM_WORLD,
 				lam_getfunc(), lam_mkerr(MPI_ERR_OP, 0));
 }
 
 void
-lam_maxloc(invec, inoutvec, len, datatype)
-
-void			*invec;
-void			*inoutvec;
-int			*len;
-MPI_Datatype		*datatype;
-
+lam_maxloc(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 {
 	int		i;
 	struct fltflt	*pffin, *pffout;
@@ -1278,13 +1515,7 @@ MPI_Datatype		*datatype;
 
 
 void
-lam_minloc(invec, inoutvec, len, datatype)
-
-void			*invec;
-void			*inoutvec;
-int			*len;
-MPI_Datatype		*datatype;
-
+lam_minloc(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 {
 	int		i;
 	struct fltflt	*pffin, *pffout;
@@ -1421,17 +1652,13 @@ MPI_Datatype		*datatype;
 }
 
 void
-lam_replace(invec, inoutvec, len, datatype)
-
-void			*invec;
-void			*inoutvec;
-int			*len;
-MPI_Datatype		*datatype;
-
+lam_replace(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 {
 	if (*datatype == MPI_INT
 		|| *datatype == MPI_F_INTEGER
 		|| *datatype == MPI_LONG
+		|| *datatype == MPI_BYTE
+		|| *datatype == MPI_UNSIGNED_CHAR
 		|| *datatype == MPI_SHORT
 		|| *datatype == MPI_UNSIGNED_SHORT
 		|| *datatype == MPI_UNSIGNED
