@@ -1,38 +1,20 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
- * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB/RBD/NJN
  *
- *	$Id: hcc.c,v 6.47.2.2 2001/10/07 19:18:09 jsquyres Exp $
+ *	$Id: hcc.c,v 6.47.2.4 2002/10/09 19:49:58 brbarret Exp $
  *
  *	Function:	- wrapper for C program compilation
  */
@@ -222,9 +204,7 @@ main(int argc, char *argv[])
  *
  * - if it's a VPATH build, lam_config.h will be in
  * LAM_TOP_BUILDDIR/share/include, and the rest will be in
- * LAM_TOP_SRCDIR/share/include.  But we also need the mpi2c++ header
- * files (ugh!), which are in LAM_TOP_SRCDIR/mpi2c++/src/mpi2c++, and
- * are referenced through LAM_TOPSRCDIR/mpi2c++/src.
+ * LAM_TOP_SRCDIR/share/include.
  *
  * - if it's not a VPATH build, everything will be in
  * LAM_TOP_SRCDIR/share/include.  So it doesn't hurt to list both
@@ -239,36 +219,21 @@ main(int argc, char *argv[])
  */
 	num_incs = 0;
 	if (fl_building) {
-	  strcpy(ph[0], "-I");
-	  strcat(ph[0], inchome);
-	  strcat(ph[0], STRSDIR);
-	  strcat(ph[0], "share");
-	  strcat(ph[0], STRSDIR);
-	  strcat(ph[0], "include");
+	  strcpy(ph[num_incs], "-I");
+	  strcat(ph[num_incs], inchome);
+	  strcat(ph[num_incs], STRSDIR);
+	  strcat(ph[num_incs], "share");
+	  strcat(ph[num_incs], STRSDIR);
+	  strcat(ph[num_incs], "include");
+	  ++num_incs;
 
-	  strcpy(ph[1], "-I");
-	  strcat(ph[1], inchome);
-	  strcat(ph[1], STRSDIR);
-	  strcat(ph[1], "mpi2c++");
-	  strcat(ph[1], STRSDIR);
-	  strcat(ph[1], "src");
-
-	  strcpy(ph[2], "-I");
-	  strcat(ph[2], inchome);
-	  strcat(ph[2], STRSDIR);
-	  strcat(ph[2], "mpi2c++");
-	  strcat(ph[2], STRSDIR);
-	  strcat(ph[2], "src");
-	  strcat(ph[2], STRSDIR);
-	  strcat(ph[2], "mpi2c++");
-
-	  strcpy(ph[3], "-I");
-	  strcat(ph[3], libhome);
-	  strcat(ph[3], STRSDIR);
-	  strcat(ph[3], "share");
-	  strcat(ph[3], STRSDIR);
-	  strcat(ph[3], "include");
-	  num_incs = 4;
+	  strcpy(ph[num_incs], "-I");
+	  strcat(ph[num_incs], libhome);
+	  strcat(ph[num_incs], STRSDIR);
+	  strcat(ph[num_incs], "share");
+	  strcat(ph[num_incs], STRSDIR);
+	  strcat(ph[num_incs], "include");
+	  ++num_incs;
 	} else {
 
 	  /* Ensure that we don't -I/usr/include, for the reasons
@@ -400,21 +365,23 @@ main(int argc, char *argv[])
 #endif
 
 #if LAM_WANT_MPI2CPP
-	  found = check_file(plib + 2, "liblammpi++.a");
-	  if (found)
-	    fl_want_mpi2cpp = 1;
-	  else {
-	    found = check_file(plib + 2, "liblammpi++.so");
+	  if (fl_compiling_cpp) {
+	    found = check_file(plib + 2, "liblammpi++.a");
 	    if (found)
 	      fl_want_mpi2cpp = 1;
 	    else {
-	      fl_want_mpi2cpp = 0;
-	      if (!fl_building) {
-		fprintf(stderr, 
-			"WARNING: %s expected to find liblammpi++.* in %s\n",
-			argv[0], plib + 2);
-		fprintf(stderr, 
-			"WARNING: MPI C++ API support will be disabled\n");
+	      found = check_file(plib + 2, "liblammpi++.so");
+	      if (found)
+		fl_want_mpi2cpp = 1;
+	      else {
+		fl_want_mpi2cpp = 0;
+		if (!fl_building) {
+		  fprintf(stderr, 
+			  "WARNING: %s expected to find liblammpi++.* in %s\n",
+			  argv[0], plib + 2);
+		  fprintf(stderr, 
+			  "WARNING: MPI C++ API support will be disabled\n");
+		}
 	      }
 	    }
 	  }
@@ -462,7 +429,7 @@ main(int argc, char *argv[])
  * hcc is used to build libmpi++.a.  Chicken and egg problem.
  */
 #if LAM_WANT_MPI2CPP
-		if (fl_want_mpi2cpp == 1) {
+		if (fl_compiling_cpp && fl_want_mpi2cpp == 1) {
 		    sfh_argv_add(&ac, &av, "-llammpi++");
 		}
 #endif
