@@ -1,38 +1,17 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
- * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	GDB/RBD/NJN
  *
- *	$Id: hf77.c,v 6.31.2.2 2001/10/07 19:18:10 jsquyres Exp $
+ * $Id: hf77.c,v 6.31.2.6 2003/01/26 19:15:54 jsquyres Exp $
  *
  *	Function:	- wrapper for FORTRAN program compilation
  */
@@ -193,10 +172,7 @@ main(int argc, char *argv[])
  *
  * - if it's a VPATH build, lam_config.h will be in
  * LAM_TOP_BUILDDIR/share/include, and the rest will be in
- * LAM_TOP_SRCDIR/share/include.  Unfortunately, we have to worry
- * about the mpi2c++ header files (since <mpi.h> may include it), so
- * we have ot put in LAM_TOP_SRCDIR/mpi2c++/src/mpi2c++, and are
- * referenced through LAM_TOPSRCDIR/mpi2c++/src.
+ * LAM_TOP_SRCDIR/share/include.  
  *
  * - if it's not a VPATH build, everything will be in
  * LAM_TOP_SRCDIR/share/include.  So it doesn't hurt to list both
@@ -204,57 +180,36 @@ main(int argc, char *argv[])
  *
  * If we're not building LAM, everything is in $prefix/include 
  *
- * Special case: if $prefix is /usr and we're not lam_building, don't
- * -I it -- this may disrupt the compiler's normal sequence of include
- * directories.  This causes a problem for some versions of RedHat
- * (and probably other distros as well), for example.  This probably
- * doesn't matter for Fortran, but we might as well make it the same
- * as hcc.
+ * Note that in hcc, if $prefix is /usr and we're not lam_building, we
+ * do *not* add -I/usr/include because that may disrupt the compiler's
+ * normal sequence of include directories.  This causes a problem for
+ * some versions of RedHat (and probably other distros as well), for
+ * example.  We do *NOT* do that here -- the fortran compiler *always*
+ * need -I, regardless of what $prefix is.
  */
 	num_incs = 0;
 	if (fl_building) {
+	  strcpy(ph[num_incs], "-I");
+	  strcat(ph[num_incs], inchome);
+	  strcat(ph[num_incs], STRSDIR);
+	  strcat(ph[num_incs], "share");
+	  strcat(ph[num_incs], STRSDIR);
+	  strcat(ph[num_incs], "include");
+	  ++num_incs;
+
+	  strcpy(ph[num_incs], "-I");
+	  strcat(ph[num_incs], libhome);
+	  strcat(ph[num_incs], STRSDIR);
+	  strcat(ph[num_incs], "share");
+	  strcat(ph[num_incs], STRSDIR);
+	  strcat(ph[num_incs], "include");
+	  ++num_incs;
+	} else {
 	  strcpy(ph[0], "-I");
 	  strcat(ph[0], inchome);
 	  strcat(ph[0], STRSDIR);
-	  strcat(ph[0], "share");
-	  strcat(ph[0], STRSDIR);
 	  strcat(ph[0], "include");
-
-	  strcpy(ph[1], "-I");
-	  strcat(ph[1], inchome);
-	  strcat(ph[1], STRSDIR);
-	  strcat(ph[1], "mpi2c++");
-	  strcat(ph[1], STRSDIR);
-	  strcat(ph[1], "src");
-
-	  strcpy(ph[2], "-I");
-	  strcat(ph[2], inchome);
-	  strcat(ph[2], STRSDIR);
-	  strcat(ph[2], "mpi2c++");
-	  strcat(ph[2], STRSDIR);
-	  strcat(ph[2], "src");
-	  strcat(ph[2], STRSDIR);
-	  strcat(ph[2], "mpi2c++");
-
-	  strcpy(ph[3], "-I");
-	  strcat(ph[3], libhome);
-	  strcat(ph[3], STRSDIR);
-	  strcat(ph[3], "share");
-	  strcat(ph[3], STRSDIR);
-	  strcat(ph[3], "include");
-	  num_incs = 4;
-	} else {
-
-	  /* Ensure that we don't -I/usr/include, for the reasons
-             listed above */
-
-	  if (strcmp(inchome, "/usr") != 0) {
-	    strcpy(ph[0], "-I");
-	    strcat(ph[0], inchome);
-	    strcat(ph[0], STRSDIR);
-	    strcat(ph[0], "include");
-	    num_incs = 1;
-	  }
+	  num_incs = 1;
 	}
 /*
  * Form library directory pathname.
@@ -264,10 +219,12 @@ main(int argc, char *argv[])
  *
  * Otherwise, use "-L$prefix/lib".
  *
- * Apply similar logic here as we did with -I -- if libhome is /usr,
- * there's no need to explicitly add it, because the compiler will
- * already be looking there.  Again, this probably doesn't matter for
- * fortran, but we might as well make it the same as for hcc.
+ * Apply similar logic here as hcc does with -I when the prefix is
+ * /usr -- if libhome is /usr, there's no need to explicitly add it,
+ * because the linker will already be looking there.  This is
+ * different than fortran's handling of -I/usr/include, but that's
+ * because the fortran compiler has different default behavior than
+ * the linker.
  */
 	num_libs = 0;
 	if (fl_building) {
@@ -293,13 +250,12 @@ main(int argc, char *argv[])
 	  /* Ensure that we don't -L/usr/lib, for the reasons listed
              above */
 
-	  if (strcmp(libhome, "/usr") != 0) {
-	    strcpy(plib[0], LAM_FLIBPATH);
-	    strcat(plib[0], libhome);
-	    strcat(plib[0], STRSDIR);
-	    strcat(plib[0], "lib");
+	  strcpy(plib[0], LAM_FLIBPATH);
+	  strcat(plib[0], libhome);
+	  strcat(plib[0], STRSDIR);
+	  strcat(plib[0], "lib");
+	  if (strcmp(libhome, "/usr") != 0)
 	    num_libs = 1;
-	  }
 	}
 
 	tf77 = getenv("LAMHF77");
@@ -360,29 +316,6 @@ main(int argc, char *argv[])
 			}
 		}
 		if (fl_building == 0) {
-/*
- * Do we want MPI 2 C++ bindings support?
- *
- * Tricky -- we have to test for presence of libmpi++.a first, "just
- * in case".  This is really only here for the obscure case where a
- * fortran module calls some other module that calls something in the
- * C++ bindings (because I don't know of any way to call C++ directly
- * from Fortran!).  
- */
-#if LAM_WANT_MPI2CPP
-		  found = check_file(plib[0] + 2, "liblammpi++.a");
-		  if (!found)
-		    found = check_file(plib[0] + 2, "liblammpi++.so");
-		  if (found)
-		    sfh_argv_add(&ac, &av, "-llammpi++");
-		  else if (!fl_building) {
-		    fprintf(stderr, 
-			    "WARNING: %s expected to find liblammpi++.* in %s\n",
-			    argv[0], plib[0] + 2);
-		    fprintf(stderr, 
-			    "WARNING: MPI C++ API support will be disabled\n");
-		  }
-#endif
 /*
  * Do we want ROMIO support?
  * Tricky -- we have to test for presence of libmpio.a first, "just in 
